Lineage Simulation Module
=========================

.. currentmodule:: plastro.lineage_simulation

The lineage simulation module provides functions for simulating CRISPR-based lineage tracing data and constructing phylogenetic trees from single-cell data.

Core Functions
--------------

.. autosummary::
   :toctree: generated/

   simulate_lineage_tracing
   construct_tree
   introduce_crispr_mutations

Utility Functions
-----------------

.. autosummary::
   :toctree: generated/

   extract_character_matrix
   save_tree_files
   generate_itol_annotations
   compute_lineage_distances

Function Details
----------------

.. automodule:: plastro.lineage_simulation
   :members:
   :undoc-members:
   :show-inheritance: